%global srcname PyOpenGL
%global shortname pyopengl

Name:           python-%{shortname}
Version:        3.1.7
Release:    2%{?dist}
Summary:        Python bindings for OpenGL
License:        BSD
URL:            https://github.com/mcfletch/pyopengl
Source0:        https://pypi.python.org/packages/source/P/%{srcname}/%{srcname}-%{version}.tar.gz
Source1:        https://pypi.python.org/packages/source/P/%{srcname}-accelerate/%{srcname}-accelerate-%{version}.tar.gz
Patch0:         python-3.12.patch

BuildRequires:  gcc
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-numpy
BuildRequires:  python3-Cython

BuildRequires:  libglvnd-opengl
BuildRequires:  mesa-dri-drivers
BuildRequires:  mesa-libGLU
BuildRequires:  python3-pygame
BuildRequires:  python3-pytest
BuildRequires:  xorg-x11-server-Xvfb

%description
PyOpenGL is the cross platform Python binding to OpenGL and related APIs. It
includes support for OpenGL v1.1, GLU, GLUT v3.7, GLE 3 and WGL 4. It also
includes support for dozens of extensions (where supported in the underlying
implementation).

PyOpenGL is inter-operable with a large number of external GUI libraries
for Python including (Tkinter, wxPython, FxPy, PyGame, and Qt). 


%package -n     python3-%{shortname}
Summary:        Python 3 bindings for OpenGL
Requires:       freeglut
Requires:       libglvnd-opengl
Requires:       python3-numpy

%description -n python3-%{shortname}
PyOpenGL is the cross platform Python binding to OpenGL and related APIs. It
includes support for OpenGL v1.1, GLU, GLUT v3.7, GLE 3 and WGL 4. It also
includes support for dozens of extensions (where supported in the underlying
implementation).

PyOpenGL is inter-operable with a large number of external GUI libraries
for Python including (Tkinter, wxPython, FxPy, PyGame, and Qt). 


%package -n     python3-%{shortname}-tk
Summary:        %{srcname} Python 3.x Tk widget
BuildArch:      noarch
Requires:       python3-%{shortname} = %{version}-%{release}
Requires:       python3-tkinter

%description -n python3-%{shortname}-tk
%{srcname} Togl (Tk OpenGL widget) 1.6 support for Python 3.x.


%prep
%setup -q -c -n %{srcname}-%{version} -T -a0 -a1
%patch -P0 -p1

%build
pushd %{srcname}-accelerate-%{version}/src
for f in *.pyx ; do
    rm -f "${f%.pyx}.c"
done
popd

for dir in %{srcname}-%{version} %{srcname}-accelerate-%{version} ; do
    pushd $dir
    %py3_build
    popd
done


%install
for dir in %{srcname}-%{version} %{srcname}-accelerate-%{version} ; do
    pushd $dir
    %py3_install
    popd
done

find %{buildroot}%{python3_sitearch}/OpenGL_accelerate/ -name *.so -exec chmod 755 '{}' \;

pushd %{buildroot}%{python3_sitelib}/OpenGL/arrays
sed -i -e '/^#! \//, 1d' buffers.py _buffers.py
popd


%check
%ifarch s390x
export PYTEST_ADDOPTS="-k 'not test_buffer_api_basic'"
%endif
PYTHONPATH=%{buildroot}%{python3_sitearch}:%{buildroot}%{python3_sitelib} \
  xvfb-run -a -s "-screen 0 1024x768x24 -ac +extension GLX +render -noreset" \
  pytest %{srcname}-%{version}/tests


%files -n python3-%{shortname}
%license %{srcname}-%{version}/license.txt
%{python3_sitelib}/%{srcname}-%{version}-py%{python3_version}.egg-info
%{python3_sitelib}/OpenGL/
%exclude %{python3_sitelib}/OpenGL/Tk
%{python3_sitearch}/OpenGL_accelerate/
%{python3_sitearch}/%{srcname}_accelerate-%{version}-py%{python3_version}.egg-info/


%files -n python3-%{shortname}-tk
%{python3_sitelib}/OpenGL/Tk


%changelog
* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 3.1.7-2
- Rebuilt for loongarch64

* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.1.7-1
- initial build
